@@ -71,8 +71,8 @@
   max.dose <- 10^100
   for(i in 1:length(doses))
   {
-    min.dose <- max(min.dose, min(as.numeric(doses[[i]]), na.rm = T), na.rm = T)
-    max.dose <- min(max.dose, max(as.numeric(doses[[i]]), na.rm = T), na.rm = T)
+    min.dose <- max(min.dose, min(as.numeric(doses[[i]]), na.rm = TRUE), na.rm = TRUE)
+    max.dose <- min(max.dose, max(as.numeric(doses[[i]]), na.rm = TRUE), na.rm = TRUE)
   }
   
   common.ranges <- list()
