@@ -44,6 +44,7 @@
 #' @importFrom graphics points
 #' @importFrom graphics lines
 #' @importFrom graphics legend
+#' @importFrom magicaxis magaxis
 
 
 drugDoseResponseCurve <- 
@@ -72,11 +73,11 @@ drugDoseResponseCurve <-
           pSetIndex[[i]] <- i
           if (length(exp_i) == 1) {
             drug.responses <- as.data.frame(cbind("Dose"=as.numeric(as.vector(pSets[[i]]@sensitivity$raw[exp_i, , "Dose"])),
-                                                "Viability"=as.numeric(as.vector(pSets[[i]]@sensitivity$raw[exp_i, , "Viability"])), stringsAsFactors=F))
+                                                "Viability"=as.numeric(as.vector(pSets[[i]]@sensitivity$raw[exp_i, , "Viability"])), stringsAsFactors=FALSE))
             drug.responses <- drug.responses[complete.cases(drug.responses), ]
           }else{
             drug.responses <- as.data.frame(cbind("Dose"=apply(pSets[[i]]@sensitivity$raw[exp_i, , "Dose"], 2, function(x){median(as.numeric(x), na.rm=TRUE)}),
-                                                  "Viability"=apply(pSets[[i]]@sensitivity$raw[exp_i, , "Viability"], 2, function(x){median(as.numeric(x), na.rm=TRUE)}), stringsAsFactors=F))
+                                                  "Viability"=apply(pSets[[i]]@sensitivity$raw[exp_i, , "Viability"], 2, function(x){median(as.numeric(x), na.rm=TRUE)}), stringsAsFactors=FALSE))
             drug.responses <- drug.responses[complete.cases(drug.responses), ]
           }
           doses[[i]] <- drug.responses$Dose
@@ -99,7 +100,7 @@ drugDoseResponseCurve <-
             pSetIndex[[j]] <- i
             
             drug.responses <- as.data.frame(cbind("Dose"=as.numeric(as.vector(pSets[[i]]@sensitivity$raw[exp, , "Dose"])),
-                                                  "Viability"=as.numeric(as.vector(pSets[[i]]@sensitivity$raw[exp, , "Viability"])), stringsAsFactors=F))
+                                                  "Viability"=as.numeric(as.vector(pSets[[i]]@sensitivity$raw[exp, , "Viability"])), stringsAsFactors=FALSE))
             drug.responses <- drug.responses[complete.cases(drug.responses), ]
             doses[[j]] <- drug.responses$Dose
             responses[[j]] <- drug.responses$Viability
